/*
 * Codepage definitions for libftxf
 *
 * Copyright (C) 2011-2022, Joachim Metz <joachim.metz@gmail.com>
 *
 * Refer to AUTHORS for acknowledgements.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#if !defined( _LIBFTXF_CODEPAGE_H )
#define _LIBFTXF_CODEPAGE_H

#include <libftxf/types.h>

#if defined( __cplusplus )
extern "C" {
#endif

/* The codepage definitions
 */
enum LIBFTXF_CODEPAGES
{
	LIBFTXF_CODEPAGE_ASCII				= 20127,

	LIBFTXF_CODEPAGE_ISO_8859_1			= 28591,
	LIBFTXF_CODEPAGE_ISO_8859_2			= 28592,
	LIBFTXF_CODEPAGE_ISO_8859_3			= 28593,
	LIBFTXF_CODEPAGE_ISO_8859_4			= 28594,
	LIBFTXF_CODEPAGE_ISO_8859_5			= 28595,
	LIBFTXF_CODEPAGE_ISO_8859_6			= 28596,
	LIBFTXF_CODEPAGE_ISO_8859_7			= 28597,
	LIBFTXF_CODEPAGE_ISO_8859_8			= 28598,
	LIBFTXF_CODEPAGE_ISO_8859_9			= 28599,
	LIBFTXF_CODEPAGE_ISO_8859_10			= 28600,
	LIBFTXF_CODEPAGE_ISO_8859_11			= 28601,
	LIBFTXF_CODEPAGE_ISO_8859_13			= 28603,
	LIBFTXF_CODEPAGE_ISO_8859_14			= 28604,
	LIBFTXF_CODEPAGE_ISO_8859_15			= 28605,
	LIBFTXF_CODEPAGE_ISO_8859_16			= 28606,

	LIBFTXF_CODEPAGE_KOI8_R				= 20866,
	LIBFTXF_CODEPAGE_KOI8_U				= 21866,

	LIBFTXF_CODEPAGE_WINDOWS_874			= 874,
	LIBFTXF_CODEPAGE_WINDOWS_932			= 932,
	LIBFTXF_CODEPAGE_WINDOWS_936			= 936,
	LIBFTXF_CODEPAGE_WINDOWS_949			= 949,
	LIBFTXF_CODEPAGE_WINDOWS_950			= 950,
	LIBFTXF_CODEPAGE_WINDOWS_1250			= 1250,
	LIBFTXF_CODEPAGE_WINDOWS_1251			= 1251,
	LIBFTXF_CODEPAGE_WINDOWS_1252			= 1252,
	LIBFTXF_CODEPAGE_WINDOWS_1253			= 1253,
	LIBFTXF_CODEPAGE_WINDOWS_1254			= 1254,
	LIBFTXF_CODEPAGE_WINDOWS_1255			= 1255,
	LIBFTXF_CODEPAGE_WINDOWS_1256			= 1256,
	LIBFTXF_CODEPAGE_WINDOWS_1257			= 1257,
	LIBFTXF_CODEPAGE_WINDOWS_1258			= 1258
};

#define LIBFTXF_CODEPAGE_US_ASCII			LIBFTXF_CODEPAGE_ASCII

#define LIBFTXF_CODEPAGE_ISO_WESTERN_EUROPEAN		LIBFTXF_CODEPAGE_ISO_8859_1
#define LIBFTXF_CODEPAGE_ISO_CENTRAL_EUROPEAN		LIBFTXF_CODEPAGE_ISO_8859_2
#define LIBFTXF_CODEPAGE_ISO_SOUTH_EUROPEAN		LIBFTXF_CODEPAGE_ISO_8859_3
#define LIBFTXF_CODEPAGE_ISO_NORTH_EUROPEAN		LIBFTXF_CODEPAGE_ISO_8859_4
#define LIBFTXF_CODEPAGE_ISO_CYRILLIC			LIBFTXF_CODEPAGE_ISO_8859_5
#define LIBFTXF_CODEPAGE_ISO_ARABIC			LIBFTXF_CODEPAGE_ISO_8859_6
#define LIBFTXF_CODEPAGE_ISO_GREEK			LIBFTXF_CODEPAGE_ISO_8859_7
#define LIBFTXF_CODEPAGE_ISO_HEBREW			LIBFTXF_CODEPAGE_ISO_8859_8
#define LIBFTXF_CODEPAGE_ISO_TURKISH			LIBFTXF_CODEPAGE_ISO_8859_9
#define LIBFTXF_CODEPAGE_ISO_NORDIC			LIBFTXF_CODEPAGE_ISO_8859_10
#define LIBFTXF_CODEPAGE_ISO_THAI			LIBFTXF_CODEPAGE_ISO_8859_11
#define LIBFTXF_CODEPAGE_ISO_BALTIC			LIBFTXF_CODEPAGE_ISO_8859_13
#define LIBFTXF_CODEPAGE_ISO_CELTIC			LIBFTXF_CODEPAGE_ISO_8859_14

#define LIBFTXF_CODEPAGE_ISO_LATIN_1			LIBFTXF_CODEPAGE_ISO_8859_1
#define LIBFTXF_CODEPAGE_ISO_LATIN_2			LIBFTXF_CODEPAGE_ISO_8859_2
#define LIBFTXF_CODEPAGE_ISO_LATIN_3			LIBFTXF_CODEPAGE_ISO_8859_3
#define LIBFTXF_CODEPAGE_ISO_LATIN_4			LIBFTXF_CODEPAGE_ISO_8859_4
#define LIBFTXF_CODEPAGE_ISO_LATIN_5			LIBFTXF_CODEPAGE_ISO_8859_9
#define LIBFTXF_CODEPAGE_ISO_LATIN_6			LIBFTXF_CODEPAGE_ISO_8859_10
#define LIBFTXF_CODEPAGE_ISO_LATIN_7			LIBFTXF_CODEPAGE_ISO_8859_13
#define LIBFTXF_CODEPAGE_ISO_LATIN_8			LIBFTXF_CODEPAGE_ISO_8859_14
#define LIBFTXF_CODEPAGE_ISO_LATIN_9			LIBFTXF_CODEPAGE_ISO_8859_15
#define LIBFTXF_CODEPAGE_ISO_LATIN_10			LIBFTXF_CODEPAGE_ISO_8859_16

#define LIBFTXF_CODEPAGE_KOI8_RUSSIAN			LIBFTXF_CODEPAGE_KOI8_R
#define LIBFTXF_CODEPAGE_KOI8_UKRAINIAN			LIBFTXF_CODEPAGE_KOI8_U

#define LIBFTXF_CODEPAGE_WINDOWS_THAI			LIBFTXF_CODEPAGE_WINDOWS_874
#define LIBFTXF_CODEPAGE_WINDOWS_JAPANESE		LIBFTXF_CODEPAGE_WINDOWS_932
#define LIBFTXF_CODEPAGE_WINDOWS_CHINESE_SIMPLIFIED	LIBFTXF_CODEPAGE_WINDOWS_936
#define LIBFTXF_CODEPAGE_WINDOWS_KOREAN			LIBFTXF_CODEPAGE_WINDOWS_949
#define LIBFTXF_CODEPAGE_WINDOWS_CHINESE_TRADITIONAL	LIBFTXF_CODEPAGE_WINDOWS_950
#define LIBFTXF_CODEPAGE_WINDOWS_CENTRAL_EUROPEAN	LIBFTXF_CODEPAGE_WINDOWS_1250
#define LIBFTXF_CODEPAGE_WINDOWS_CYRILLIC		LIBFTXF_CODEPAGE_WINDOWS_1251
#define LIBFTXF_CODEPAGE_WINDOWS_WESTERN_EUROPEAN	LIBFTXF_CODEPAGE_WINDOWS_1252
#define LIBFTXF_CODEPAGE_WINDOWS_GREEK			LIBFTXF_CODEPAGE_WINDOWS_1253
#define LIBFTXF_CODEPAGE_WINDOWS_TURKISH		LIBFTXF_CODEPAGE_WINDOWS_1254
#define LIBFTXF_CODEPAGE_WINDOWS_HEBREW			LIBFTXF_CODEPAGE_WINDOWS_1255
#define LIBFTXF_CODEPAGE_WINDOWS_ARABIC			LIBFTXF_CODEPAGE_WINDOWS_1256
#define LIBFTXF_CODEPAGE_WINDOWS_BALTIC			LIBFTXF_CODEPAGE_WINDOWS_1257
#define LIBFTXF_CODEPAGE_WINDOWS_VIETNAMESE		LIBFTXF_CODEPAGE_WINDOWS_1258

#if defined( __cplusplus )
}
#endif

#endif /* !defined( _LIBFTXF_CODEPAGE_H ) */

